.. _traceAnalysisClass:

Analysis of Markov-Chains
================================

The class *TraceAnalysis* provides some convenient methods
to carry out an analysis of the Markov-Chains resulting from
an MCMC "fit".

Examples for using the class are given in the associated tutorial: :ref:`traceAnalysisTut`

.. currentmodule:: PyAstronomy.funcFit
.. autoclass:: TraceAnalysis
   :members:

.. autofunction:: hpd
.. autofunction:: quantiles
.. autofunction:: modeGrenander

